@@ -1,5 +1,4 @@
 #! /usr/bin/env python
-import sys
 from dns import resolver, reversename, exception
 from harpoon.commands.base import Command
 from harpoon.lib.utils import is_ip, unbracket
@@ -20,7 +19,8 @@ class CommandDns(Command):
     name = "dns"
     description = "Map DNS information for a domain or an IP"
     config = {}
-    all_types = ['NONE', 'A', 'NS', 'MD', 'MF', 'CNAME', 'SOA', 'MB', 'MG',
+    all_types = [
+        'NONE', 'A', 'NS', 'MD', 'MF', 'CNAME', 'SOA', 'MB', 'MG',
         'MR', 'NULL', 'WKS', 'PTR', 'HINFO', 'MINFO', 'MX', 'TXT', 'RP',
         'AFSDB', 'X25', 'ISDN', 'RT', 'NSAP', 'NSAP-PTR', 'SIG', 'KEY',
         'PX', 'GPOS', 'AAAA', 'LOC', 'NXT', 'SRV', 'NAPTR', 'KX', 'CERT',
@@ -32,20 +32,21 @@ class CommandDns(Command):
 
     def add_arguments(self, parser):
         parser.add_argument('TARGET', help='Domain or IP to query')
-        parser.add_argument('--extended', '-e', action='store_true',
-                help="Extended testing of all DNS types")
+        parser.add_argument(
+            '--extended', '-e', action='store_true',
+            help="Extended testing of all DNS types")
         self.parser = parser
 
     def owner_to_email(self, owner):
         rev = owner[:-1].split('.')
         return '.'.join(rev[:-2]) + "@" + ".".join(rev[-2:])
 
-    def run(self, conf, args, plugins):
+    def run(self, args, plugins):
         if is_ip(unbracket(args.TARGET)):
             # That's an IP address
             ptr_n = str(reversename.from_address(unbracket(args.TARGET)))
             try:
-                answer = [entry for entry in resolver.query(ptr_n, "PTR")][0]
+                answer = [entry for entry in resolver.resolve(ptr_n, "PTR")][0]
                 print("%s - %s" % (ptr_n, str(answer)))
             except (resolver.NXDOMAIN, resolver.NoAnswer):
                 print("%s - %s" % (ptr_n, "NXDOMAIN"))
@@ -54,17 +55,17 @@ class CommandDns(Command):
             if args.extended:
                 for a in self.all_types:
                     try:
-                        answers = resolver.query(unbracket(args.TARGET), a)
+                        answers = resolver.resolve(unbracket(args.TARGET), a)
                         for rdata in answers:
                             print(a, ':', rdata.to_text())
-                    except Exception as e:
+                    except Exception:
                         pass
             else:
                 target = unbracket(args.TARGET)
                 # A
                 print("# A")
                 try:
-                    answers = resolver.query(target, 'A')
+                    answers = resolver.resolve(target, 'A')
                 except (resolver.NoAnswer, resolver.NXDOMAIN):
                     print("No A entry")
                 except resolver.NoNameservers:
@@ -87,7 +88,7 @@ class CommandDns(Command):
                 print("")
                 print("# AAAA")
                 try:
-                    answers = resolver.query(target, 'AAAA')
+                    answers = resolver.resolve(target, 'AAAA')
                     for rdata in answers:
                         print(rdata.address)
                 except (resolver.NoAnswer, resolver.NXDOMAIN):
@@ -100,7 +101,7 @@ class CommandDns(Command):
                 # DNS Servers
                 print("\n# NS")
                 try:
-                    answers = resolver.query(target, 'NS')
+                    answers = resolver.resolve(target, 'NS')
                 except (resolver.NoAnswer, resolver.NXDOMAIN, resolver.NoNameservers):
                     # That's pretty unlikely
                     print("No NS entry configured")
@@ -122,7 +123,7 @@ class CommandDns(Command):
                             )
                         else:
                             try:
-                                ip = [b.address for b in resolver.query(ttarget, 'A')][0]
+                                ip = [b.address for b in resolver.resolve(ttarget, 'A')][0]
                             except resolver.NXDOMAIN:
                                 # Hostname without IPv4
                                 print(ttarget)
@@ -142,7 +143,7 @@ class CommandDns(Command):
                 # MX
                 print("\n# MX:")
                 try:
-                    answers = resolver.query(target, 'MX')
+                    answers = resolver.resolve(target, 'MX')
                 except (resolver.NoAnswer, resolver.NXDOMAIN):
                     print("No MX entry configured")
                 except resolver.NoNameservers:
@@ -165,7 +166,7 @@ class CommandDns(Command):
                             )
                         else:
                             try:
-                                ip = [b.address for b in resolver.query(rdata.exchange, 'A')][0]
+                                ip = [b.address for b in resolver.resolve(rdata.exchange, 'A')][0]
                             except (resolver.NoAnswer, resolver.NXDOMAIN):
                                 # Hostname without IPv4
                                 print("%i %s" % (rdata.preference, rdata.exchange))
@@ -186,7 +187,7 @@ class CommandDns(Command):
                 # SOA
                 print("\n# SOA")
                 try:
-                    answers = resolver.query(target, 'SOA')
+                    answers = resolver.resolve(target, 'SOA')
                 except (resolver.NoAnswer, resolver.NXDOMAIN):
                     print("No SOA entry configured")
                 except resolver.NoNameservers:
@@ -201,7 +202,7 @@ class CommandDns(Command):
                 # TXT
                 print("\n# TXT:")
                 try:
-                    answers = resolver.query(target, 'TXT')
+                    answers = resolver.resolve(target, 'TXT')
                 except (resolver.NoAnswer, resolver.NXDOMAIN):
                     print("No TXT entry configured")
                 except resolver.NoNameservers:
