@@ -3,6 +3,7 @@ import sys
 import json
 import datetime
 import pytz
+import requests
 from dateutil.parser import parse
 from harpoon.commands.base import Command
 from harpoon.lib.utils import bracket, unbracket
@@ -38,21 +39,44 @@ class CommandPassiveTotal(Command):
         parser_b.set_defaults(subcommand='dns')
         parser_c = subparsers.add_parser('malware', help='Request malware info')
         parser_c.add_argument('--domain', '-d',  help='DOMAIN to be queried')
-        parser_c.add_argument('--file', '-f',  help='Check malware info from a domain list in a file and return csv of results')
+        parser_c.add_argument(
+            '--file', '-f',
+            help='Check malware info from a domain list in a file and return csv of results')
         parser_c.add_argument('--raw', '-r',  help='Show raw results (JSON)', action="store_true")
         parser_c.set_defaults(subcommand='malware')
         parser_d = subparsers.add_parser('osint', help='Request OSINT info')
         parser_d.add_argument('--domain', '-d',  help='DOMAIN to be queried')
-        parser_d.add_argument('--file', '-f',  help='Check OSINT info from a domain list in a file and return csv of results')
+        parser_d.add_argument(
+            '--file', '-f',
+            help='Check OSINT info from a domain list in a file and return csv of results')
         parser_d.add_argument('--raw', '-r',  help='Show raw results (JSON)', action="store_true")
         parser_d.set_defaults(subcommand='osint')
+        parser_e = subparsers.add_parser('subdomains', help='Get subdomains of a domain')
+        parser_e.add_argument('DOMAIN', help='DOMAIN to be queried')
+        parser_e.set_defaults(subcommand='subdomains')
         self.parser = parser
 
+    def get_subdomains(self, domain):
+        """
+        Get and show subdomains of a domain
+        """
+        client = EnrichmentRequest(
+            self._config_data['PassiveTotal']['username'],
+            self._config_data['PassiveTotal']['key'])
 
-    def run(self, conf, args, plugins):
+        res = client.get_subdomains(
+            query=domain,
+            field="domain"
+        )
+        for d in res["subdomains"]:
+            print(d)
+
+    def run(self, args, plugins):
         if 'subcommand' in args:
             if args.subcommand == 'whois':
-                client = WhoisRequest(conf['PassiveTotal']['username'], conf['PassiveTotal']['key'])
+                client = WhoisRequest(
+                    self._config_data['PassiveTotal']['username'],
+                    self._config_data['PassiveTotal']['key'])
                 if args.domain:
                     raw_results = client.search_whois_by_field(
                         query=unbracket(args.domain.strip()),
@@ -71,10 +95,10 @@ class CommandPassiveTotal(Command):
                             field="domain"
                         )
                         if "results" not in raw_results:
-                            print("%s|||||||||||" %  bracket(do) )
+                            print("%s|||||||||||" % bracket(do))
                         else:
                             if len(raw_results["results"]) == 0:
-                                print("%s|||||||||||" %  bracket(do) )
+                                print("%s|||||||||||" % bracket(do))
                             else:
                                 r = raw_results["results"][0]
                                 if "registered" in r:
@@ -99,7 +123,6 @@ class CommandPassiveTotal(Command):
                                     )
                                 )
 
-
                 elif args.email:
                     raw_results = client.search_whois_by_field(
                         query=args.email.strip(),
@@ -109,13 +132,17 @@ class CommandPassiveTotal(Command):
                 else:
                     self.parser.print_help()
             elif args.subcommand == "dns":
-                client = DnsRequest(conf['PassiveTotal']['username'], conf['PassiveTotal']['key'])
+                client = DnsRequest(
+                    self._config_data['PassiveTotal']['username'],
+                    self._config_data['PassiveTotal']['key'])
                 raw_results = client.get_passive_dns(
                     query=unbracket(args.DOMAIN),
                 )
                 print(json.dumps(raw_results,  sort_keys=True, indent=4, separators=(',', ': ')))
             elif args.subcommand == "malware":
-                client = EnrichmentRequest(conf["PassiveTotal"]["username"], conf["PassiveTotal"]['key'])
+                client = EnrichmentRequest(
+                    self._config_data["PassiveTotal"]["username"],
+                    self._config_data["PassiveTotal"]['key'])
                 if args.domain:
                     raw_results = client.get_malware(query=args.domain)
                     print(json.dumps(raw_results,  sort_keys=True, indent=4, separators=(',', ': ')))
@@ -133,7 +160,7 @@ class CommandPassiveTotal(Command):
                             results = raw_results["results"]
                     else:
                         results = {}
-                        bulk_size=50
+                        bulk_size = 50
                         i = 0
                         while i*bulk_size < len(domain_list):
                             raw_results = client.get_bulk_malware(query=domain_list[i*bulk_size:(i+1)*bulk_size])
@@ -152,20 +179,21 @@ class CommandPassiveTotal(Command):
                             if "results" in results[domain]:
                                 for sample in results[domain]["results"]:
                                     print("%s|%s|%s|%s|%s" % (
-                                                domain,
-                                                sample["collectionDate"],
-                                                sample["sample"],
-                                                sample["source"],
-                                                sample["sourceUrl"]
-                                            )
-                                        )
+                                        domain,
+                                        sample["collectionDate"],
+                                        sample["sample"],
+                                        sample["source"],
+                                        sample["sourceUrl"]
+                                    ))
 
                 else:
                     self.parser.print_help()
 
             elif args.subcommand == "osint":
                 # FIXME: add research of projects
-                client = EnrichmentRequest(conf["PassiveTotal"]["username"], conf["PassiveTotal"]['key'])
+                client = EnrichmentRequest(
+                        self._config_data["PassiveTotal"]["username"],
+                        self._config_data["PassiveTotal"]['key'])
                 if args.domain:
                     raw_results = client.get_osint(query=args.domain)
                     print(json.dumps(raw_results,  sort_keys=True, indent=4, separators=(',', ': ')))
@@ -183,7 +211,7 @@ class CommandPassiveTotal(Command):
                             results = raw_results["results"]
                     else:
                         results = {}
-                        bulk_size=50
+                        bulk_size = 50
                         i = 0
                         while i*bulk_size < len(domain_list):
                             raw_results = client.get_bulk_osint(query=domain_list[i*bulk_size:(i+1)*bulk_size])
@@ -210,130 +238,158 @@ class CommandPassiveTotal(Command):
                                     )
                 else:
                     self.parser.print_help()
-
+            elif args.subcommand == "subdomains":
+                self.get_subdomains(unbracket(args.DOMAIN))
             else:
                 self.parser.print_help()
         else:
             self.parser.print_help()
 
-    def intel(self, type, query, data, conf):
-        if type == "domain":
-            print("[+] Checking Passive Total...")
-            try:
-                pt_osint = {}
-                ptout = False
-                client = DnsRequest(
-                    conf["PassiveTotal"]["username"],
-                    conf["PassiveTotal"]["key"],
+    def intel_domain(self, query, data):
+        print("[+] Checking Passive Total...")
+        try:
+            pt_osint = {}
+            ptout = False
+            client = DnsRequest(
+                self._config_data["PassiveTotal"]["username"],
+                self._config_data["PassiveTotal"]["key"],
+            )
+            raw_results = client.get_passive_dns(query=query)
+            if "results" in raw_results:
+                for res in raw_results["results"]:
+                    data["passive_dns"].append(
+                        {
+                            "first": parse(res["firstSeen"]).astimezone(
+                                pytz.utc
+                            ),
+                            "last": parse(res["lastSeen"]).astimezone(
+                                pytz.utc
+                            ),
+                            "ip": res["resolve"],
+                            "source": "PT",
+                        }
+                    )
+            if "message" in raw_results:
+                if "quota_exceeded" in raw_results["message"]:
+                    print("PT quota exceeded")
+                    ptout = True
+            if not ptout:
+                client2 = EnrichmentRequest(
+                    self._config_data["PassiveTotal"]["username"],
+                    self._config_data["PassiveTotal"]["key"],
+                )
+                # Get OSINT
+                pt_osint = client2.get_osint(query=query)
+                if "results" in pt_osint:
+                    for r in pt_osint["results"]:
+                        data["reports"].append({
+                            "date": "",
+                            "title": r["name"] if "name" in r else "",
+                            "url": r["sourceUrl"],
+                            "source": "PT"
+                        })
+                # Get malware
+                raw_results = client2.get_malware(
+                    query=query
                 )
-                raw_results = client.get_passive_dns(query=query)
                 if "results" in raw_results:
-                    for res in raw_results["results"]:
-                        data["passive_dns"].append(
+                    for r in raw_results["results"]:
+                        data["malware"].append(
                             {
-                                "first": parse(res["firstSeen"]).astimezone(
-                                    pytz.utc
-                                ),
-                                "last": parse(res["lastSeen"]).astimezone(
-                                    pytz.utc
-                                ),
-                                "ip": res["resolve"],
-                                "source": "PT",
+                                "hash": r["sample"],
+                                "date": parse(
+                                    r["collectionDate"]
+                                ).astimezone(pytz.utc),
+                                "source": "PT (%s)" % r["source"],
                             }
                         )
-                if "message" in raw_results:
-                    if "quota_exceeded" in raw_results["message"]:
-                        print("PT quota exceeded")
-                        ptout = True
-                if not ptout:
-                    client2 = EnrichmentRequest(
-                        conf["PassiveTotal"]["username"],
-                        conf["PassiveTotal"]["key"],
+        except requests.exceptions.ReadTimeout:
+            print("PT: Time Out")
+
+    def intel_ip(self, query, data):
+        print("[+] Checking Passive Total...")
+        try:
+            pt_osint = {}
+            ptout = False
+            client = DnsRequest(
+                self._config_data["PassiveTotal"]["username"],
+                self._config_data["PassiveTotal"]["key"],
+            )
+            raw_results = client.get_passive_dns(query=query)
+            if "results" in raw_results:
+                for res in raw_results["results"]:
+                    data["passive_dns"].append(
+                        {
+                            "first": parse(res["firstSeen"]).astimezone(
+                                pytz.utc
+                            ),
+                            "last": parse(res["lastSeen"]).astimezone(
+                                pytz.utc
+                            ),
+                            "domain": res["resolve"],
+                            "source": "PT",
+                        }
                     )
-                    # Get OSINT
-                    pt_osint = client2.get_osint(query=query)
-                    if "results" in pt_osint:
-                        for r in pt_osint["results"]:
-                            data["reports"].append({
-                                "date": "",
-                                "title": r["name"] if "name" in r else "",
-                                "url": r["sourceUrl"],
-                                "source": "PT"
-                            })
-                    # Get malware
-                    raw_results = client2.get_malware(
-                        query=query
-                    )
-                    if "results" in raw_results:
-                        for r in raw_results["results"]:
-                            data["malware"].append(
-                                {
-                                    "hash": r["sample"],
-                                    "date": parse(
-                                        r["collectionDate"]
-                                    ).astimezone(pytz.utc),
-                                    "source": "PT (%s)" % r["source"],
-                                }
-                            )
-            except requests.exceptions.ReadTimeout:
-                print("PT: Time Out")
-        elif type == "ip":
-            print("[+] Checking Passive Total...")
-            try:
-                pt_osint = {}
-                ptout = False
-                client = DnsRequest(
-                    conf["PassiveTotal"]["username"],
-                    conf["PassiveTotal"]["key"],
+            if "message" in raw_results:
+                if "quota_exceeded" in raw_results["message"]:
+                    print("PT quota exceeded")
+                    ptout = True
+            if not ptout:
+                client2 = EnrichmentRequest(
+                    self._config_data["PassiveTotal"]["username"],
+                    self._config_data["PassiveTotal"]["key"],
+                )
+                # Get OSINT
+                pt_osint = client2.get_osint(query=query)
+                if "results" in pt_osint:
+                    for r in pt_osint["results"]:
+                        data["reports"].append({
+                            "date": "",
+                            "title": r["name"] if "name" in r else "",
+                            "url": r["sourceUrl"],
+                            "source": "PT"
+                        })
+                # Get malware
+                raw_results = client2.get_malware(
+                    query=query
                 )
-                raw_results = client.get_passive_dns(query=query)
                 if "results" in raw_results:
-                    for res in raw_results["results"]:
-                        data["passive_dns"].append(
+                    for r in raw_results["results"]:
+                        data["malware"].append(
                             {
-                                "first": parse(res["firstSeen"]).astimezone(
-                                    pytz.utc
-                                ),
-                                "last": parse(res["lastSeen"]).astimezone(
-                                    pytz.utc
-                                ),
-                                "domain": res["resolve"],
-                                "source": "PT",
+                                "hash": r["sample"],
+                                "date": parse(
+                                    r["collectionDate"]
+                                ).astimezone(pytz.utc),
+                                "source": "PT (%s)" % r["source"],
                             }
                         )
-                if "message" in raw_results:
-                    if "quota_exceeded" in raw_results["message"]:
-                        print("PT quota exceeded")
-                        ptout = True
-                if not ptout:
-                    client2 = EnrichmentRequest(
-                        conf["PassiveTotal"]["username"],
-                        conf["PassiveTotal"]["key"],
-                    )
-                    # Get OSINT
-                    pt_osint = client2.get_osint(query=query)
-                    if "results" in pt_osint:
-                        for r in pt_osint["results"]:
-                            data["reports"].append({
-                                "date": "",
-                                "title": r["name"] if "name" in r else "",
-                                "url": r["sourceUrl"],
-                                "source": "PT"
-                            })
-                    # Get malware
-                    raw_results = client2.get_malware(
-                        query=query
-                    )
-                    if "results" in raw_results:
-                        for r in raw_results["results"]:
-                            data["malware"].append(
-                                {
-                                    "hash": r["sample"],
-                                    "date": parse(
-                                        r["collectionDate"]
-                                    ).astimezone(pytz.utc),
-                                    "source": "PT (%s)" % r["source"],
-                                }
-                            )
-            except requests.exceptions.ReadTimeout:
-                print("PT: Time Out")
+        except requests.exceptions.ReadTimeout:
+            print("PT: Time Out")
+
+    def intel_email(self, query, data):
+        print("[+] Checking Passive Total...")
+        client = WhoisRequest(
+            self._config_data['PassiveTotal']['username'],
+            self._config_data['PassiveTotal']['key']
+        )
+        raw_results = client.search_whois_by_field(
+            query=query,
+            field="email")
+
+        if "results" in raw_results:
+            for res in raw_results["results"]:
+                # Concat all other interesting infos
+                other_infos = []
+                for a in ["admin", "tech", "registrant"]:
+                    if a in res:
+                        for b in ["email", "name", "organization", "telephone"]:
+                            if b in res[a]:
+                                if res[a][b] not in other_infos:
+                                    other_infos.append(
+                                        res[a][b])
+                data["domains"].append({
+                    "registered": res["registered"][:10],
+                    "domain": res["domain"],
+                    "infos": other_infos
+                })
