@@ -1,13 +1,9 @@
 #! /usr/bin/env python
-import sys
-import operator
 import json
 import pytz
-from dateutil.parser import parse
 from harpoon.commands.base import Command
 from harpoon.lib.robtex import Robtex, RobtexError
 from harpoon.lib.utils import json_serial, unbracket
-from datetime import date, datetime
 
 
 class CommandRobtex(Command):
@@ -42,7 +38,7 @@ class CommandRobtex(Command):
         parser_c.set_defaults(subcommand='domain')
         self.parser = parser
 
-    def run(self, conf, args, plugins):
+    def run(self, args, plugins):
         if 'subcommand' in args:
             if args.subcommand == "ip":
                 r = Robtex()
@@ -107,7 +103,7 @@ class CommandRobtex(Command):
         else:
             self.parser.print_help()
 
-    def intel(self, type, query, data, conf):
+    def intel(self, type, query, data):
         if type == "domain":
             print("[+] Checking Robtex....")
             try:
@@ -143,5 +139,3 @@ class CommandRobtex(Command):
                             )
             except RobtexError:
                 print("Robtex query failed")
-
-
