@@ -1,11 +1,9 @@
 #! /usr/bin/env python
-import sys
 import json
-import hashlib
 import pytz
 from dateutil.parser import parse
 from harpoon.commands.base import Command
-from harpoon.lib.utils import json_serial, typeguess, unbracket
+from harpoon.lib.utils import typeguess, unbracket
 from pythreatgrid2 import ThreatGrid, ThreatGridError
 
 
@@ -29,18 +27,24 @@ class CommandThreatGrid(Command):
         parser_a.add_argument('HASH', help='Hash')
         parser_a.add_argument('--json', '-j', action='store_true', help='Show raw json')
         parser_a.set_defaults(subcommand='hash')
-        parser_b = subparsers.add_parser('search', help='Search in Total Hash database')
+        parser_b = subparsers.add_parser('search', help='Search in ThreatGrid database')
         parser_b.add_argument('--json', '-j', action='store_true', help='Show raw json')
-        parser_b.add_argument('TYPE', help='type of the query (can be checksum, checksum_sample, path, path_sample, path_artifact, path_deleted, url, registry_key, domain, domain_dns_lookup, domain_http_request, ip, ip_dns_lookup, ip_src, ip_dst, ioc, tag)')
+        parser_b.add_argument(
+            'TYPE',
+            help='type of the query (can be checksum, checksum_sample, path,' +
+            'path_sample, path_artifact, path_deleted, url, registry_key, ' +
+            'domain, domain_dns_lookup, domain_http_request, ip, ip_dns_lookup, ip_src, ip_dst, ioc, tag)')
         parser_b.add_argument('QUERY', help='query')
         parser_b.set_defaults(subcommand='search')
-        parser_c = subparsers.add_parser('networklist', help='Read list of network indicators (domain or IP) from a file a search for related samples')
+        parser_c = subparsers.add_parser(
+            'networklist',
+            help='Read list of network indicators (domain or IP) from a file a search for related samples')
         parser_c.add_argument('FILE', help='File')
         parser_c.set_defaults(subcommand='networklist')
         self.parser = parser
 
-    def run(self, conf, args, plugins):
-        tg = ThreatGrid(conf['ThreatGrid']['key'])
+    def run(self, args, plugins):
+        tg = ThreatGrid(self._config_data['ThreatGrid']['key'])
         if 'subcommand' in args:
             if args.subcommand == "search":
                 try:
@@ -56,14 +60,20 @@ class CommandThreatGrid(Command):
                         already = []
                         for item in res['items']:
                             if item['sample_sha256'] not in already:
-                                print("%s - %s - %s" % (item['ts'], item['sample_sha256'], "https://panacea.threatgrid.com/mask/samples/" + item['sample']))
+                                print("%s - %s - %s" % (
+                                    item['ts'],
+                                    item['sample_sha256'],
+                                    "https://panacea.threatgrid.com/mask/samples/" + item['sample']
+                                ))
                                 already.append(item['sample_sha256'])
             elif args.subcommand == 'hash':
                 hash_type = {32: 'md5', 40: 'sha1', 64: 'sha256'}
                 res = tg.get_sample(args.HASH, type=hash_type[len(args.HASH)])
                 if len(res['items']) > 0:
                     item = res['items'][0]
-                    print("Sample submitted the %s: https://panacea.threatgrid.com/mask/samples/%s" % (item['submitted_at'], item['id']))
+                    print("Sample submitted the %s: https://panacea.threatgrid.com/mask/samples/%s" % (
+                        item['submitted_at'],
+                        item['id']))
                     idd = item['id']
                     res = tg.get_sample_threats(idd)
                     if args.json:
@@ -86,7 +96,10 @@ class CommandThreatGrid(Command):
                         already = []
                         for item in res['items']:
                             if item['sample_sha256'] not in already:
-                                print("-%s: https://panacea.threatgrid.com/mask/samples/%s %s" % (item['ts'][:10], item['sample'], item['sample_sha256']))
+                                print("-%s: https://panacea.threatgrid.com/mask/samples/%s %s" % (
+                                    item['ts'][:10],
+                                    item['sample'],
+                                    item['sample_sha256']))
                                 already.append(item['sample_sha256'])
 
                     else:
@@ -97,11 +110,11 @@ class CommandThreatGrid(Command):
         else:
             self.parser.print_help()
 
-    def intel(self, type, query, data, conf):
+    def intel(self, type, query, data):
         if type == "domain":
             print("[+] Checking ThreatGrid...")
             try:
-                tg = ThreatGrid(conf["ThreatGrid"]["key"])
+                tg = ThreatGrid(self._config_data["ThreatGrid"]["key"])
                 res = tg.search_samples(query, type="domain")
                 already = []
                 if "items" in res:
@@ -121,7 +134,7 @@ class CommandThreatGrid(Command):
         elif type == "ip":
             print("[+] Checking ThreatGrid...")
             try:
-                tg = ThreatGrid(conf["ThreatGrid"]["key"])
+                tg = ThreatGrid(self._config_data["ThreatGrid"]["key"])
                 res = tg.search_samples(query, type="ip")
                 already = []
                 if "items" in res:
@@ -138,10 +151,10 @@ class CommandThreatGrid(Command):
                             already.append(r["sample_sha256"])
             except ThreatGridError as e:
                 print("Failed to connect to Threat Grid: %s" % e.message)
-        elif type =="hash":
+        elif type == "hash":
             print("[+] Checking ThreatGrid...")
             try:
-                tg = ThreatGrid(conf["ThreatGrid"]["key"])
+                tg = ThreatGrid(self._config_data["ThreatGrid"]["key"])
                 hash_type = {32: 'md5', 40: 'sha1', 64: 'sha256'}
                 res = tg.get_sample(query, type=hash_type[len(query)])
                 for item in res["items"]:
