@@ -4,6 +4,7 @@ import json
 import hashlib
 import os
 import pytz
+import time
 from dateutil.parser import parse
 from harpoon.commands.base import Command
 from virus_total_apis import PublicApi, PrivateApi
@@ -161,10 +162,10 @@ class CommandVirusTotal(Command):
             print("[+] Last Seen: %s" % response["results"]["last_seen"])
         print("[+] Link: %s" % response["results"]["permalink"])
 
-    def run(self, conf, args, plugins):
+    def run(self, args, plugins):
         if 'subcommand' in args:
-            if conf["VirusTotal"]["type"] != "public":
-                vt = PrivateApi(conf["VirusTotal"]["key"])
+            if self._config_data["VirusTotal"]["type"] != "public":
+                vt = PrivateApi(self._config_data["VirusTotal"]["key"])
                 if args.subcommand == "hash":
                     response = vt.get_file_report(args.HASH)
                     if args.raw:
@@ -222,17 +223,18 @@ class CommandVirusTotal(Command):
                             if response["results"]["response_code"] == 0:
                                 print("%s;Not found;;;;;" % h)
                             else:
-                                print("%s;Found;%i;%i;%s;%s;%s" % (
+                                print("{};Found;{};{};{};{}".format(
                                         h,
                                         response["results"]["positives"],
                                         response["results"]["total"],
-                                        response["results"]["first_seen"],
-                                        response["results"]["last_seen"],
+                                        response["results"]["scan_date"],
                                         response["results"]["permalink"]
                                     )
                                 )
                         else:
                             print("%s;Not found;;;;;" % h)
+                        # Max 4 requests per minute
+                        time.sleep(15)
                 elif args.subcommand == "domainlist":
                     with open(args.FILE, 'r') as infile:
                         data = infile.read().split()
@@ -262,7 +264,7 @@ class CommandVirusTotal(Command):
                 else:
                     self.parser.print_help()
             else:
-                vt = PublicApi(conf["VirusTotal"]["key"])
+                vt = PublicApi(self._config_data["VirusTotal"]["key"])
                 if args.subcommand == "hash":
                     response = vt.get_file_report(args.HASH)
                     if args.raw:
@@ -327,11 +329,11 @@ class CommandVirusTotal(Command):
         else:
             self.parser.print_help()
 
-    def intel(self, type, query, data, conf):
+    def intel(self, type, query, data):
         if type == "domain":
-            if conf["VirusTotal"]["type"] != "public":
+            if self._config_data["VirusTotal"]["type"] != "public":
                 print("[+] Checking VirusTotal....")
-                vt = PrivateApi(conf["VirusTotal"]["key"])
+                vt = PrivateApi(self._config_data["VirusTotal"]["key"])
                 res = vt.get_domain_report(query)
                 if "results" in res:
                     if "resolutions" in res["results"]:
@@ -428,9 +430,9 @@ class CommandVirusTotal(Command):
                                 }
                             )
         elif type == "ip":
-            if conf["VirusTotal"]["type"] != "public":
+            if self._config_data["VirusTotal"]["type"] != "public":
                 print("[+] Checking VirusTotal...")
-                vt = PrivateApi(conf["VirusTotal"]["key"])
+                vt = PrivateApi(self._config_data["VirusTotal"]["key"])
                 res = vt.get_ip_report(query)
                 if "results" in res:
                     if "resolutions" in res["results"]:
@@ -515,9 +517,9 @@ class CommandVirusTotal(Command):
                                 }
                             )
         elif type == "hash":
-            if conf["VirusTotal"]["type"] != "public":
+            if self._config_data["VirusTotal"]["type"] != "public":
                 print("[+] Checking VirusTotal...")
-                vt = PrivateApi(conf["VirusTotal"]["key"])
+                vt = PrivateApi(self._config_data["VirusTotal"]["key"])
                 res = vt.get_file_report(query)
                 if res["results"]["response_code"] == 1:
                     # Found
