@@ -1,5 +1,4 @@
 #! /usr/bin/env python
-import sys
 import json
 import re
 import pytz
@@ -21,7 +20,9 @@ class CommandZetalytics(Command):
 
     def add_arguments(self, parser):
         subparsers = parser.add_subparsers(help='Subcommand')
-        parser_a = subparsers.add_parser('cname2qname', help='Search passive dns by CNAME value (target of CNAME record)')
+        parser_a = subparsers.add_parser(
+            'cname2qname',
+            help='Search passive dns by CNAME value (target of CNAME record)')
         parser_a.add_argument('CNAME',  help='CNAME value to query (matches subdomains)')
         parser_a.add_argument('--json', '-j', action='store_true', help='Show raw JSON info')
         parser_a.set_defaults(subcommand='cname2qname')
@@ -54,7 +55,9 @@ class CommandZetalytics(Command):
         parser_i.add_argument('--json', '-j', action='store_true', help='Show raw JSON info')
         parser_i.add_argument('DOMAIN',  help='Domain')
         parser_i.set_defaults(subcommand='domain2ns')
-        parser_j = subparsers.add_parser('domain2nsglue', help='Search name server glue (IP) records by domain name. NOTE: these are only the glue records found in gTLD zone files and NOT all IP records for every name server domain.')
+        parser_j = subparsers.add_parser(
+            'domain2nsglue',
+            help='Search name server glue (IP) records by domain name.')
         parser_j.add_argument('DOMAIN',  help='Domain')
         parser_j.set_defaults(subcommand='domain2nsglue')
         parser_k = subparsers.add_parser('domain2ptr', help='Search passive dns by domain for PTR records')
@@ -68,14 +71,20 @@ class CommandZetalytics(Command):
         parser_m = subparsers.add_parser('domain2whois', help='Search historical whois records')
         parser_m.add_argument('DOMAIN',  help='Domain')
         parser_m.set_defaults(subcommand='domain2whois')
-        parser_n = subparsers.add_parser('email_address', help='Search for domains sharing a registration email address or SOA email from passive')
+        parser_n = subparsers.add_parser(
+            'email_address',
+            help='Search for domains sharing a registration email address or SOA email from passive')
         parser_n.add_argument('EMAIL',  help='Email address')
         parser_n.add_argument('--json', '-j', action='store_true', help='Show raw JSON info')
         parser_n.set_defaults(subcommand='email_address')
-        parser_o = subparsers.add_parser('email_domain', help='Search for domains sharing a registration email address domain')
+        parser_o = subparsers.add_parser(
+            'email_domain',
+            help='Search for domains sharing a registration email address domain')
         parser_o.add_argument('EMAIL',  help='Email address')
         parser_o.set_defaults(subcommand='email_domain')
-        parser_p = subparsers.add_parser('email_user', help='Search for domains sharing a registration email address or SOA email from passive')
+        parser_p = subparsers.add_parser(
+            'email_user',
+            help='Search for domains sharing a registration email address or SOA email from passive')
         parser_p.add_argument('EMAIL',  help='Email address')
         parser_p.set_defaults(subcommand='email_user')
         parser_q = subparsers.add_parser('hash2malwaredns', help='Search malware dns by md5 hash')
@@ -84,7 +93,9 @@ class CommandZetalytics(Command):
         parser_r = subparsers.add_parser('hash2malwarehttp', help='Search malware http by md5 hash')
         parser_r.add_argument('HASH',  help='Md5 hash')
         parser_r.set_defaults(subcommand='hash2malwarehttp')
-        parser_s = subparsers.add_parser('hostname', help='Search passive dns by hostname for mixed resource record types')
+        parser_s = subparsers.add_parser(
+            'hostname',
+            help='Search passive dns by hostname for mixed resource record types')
         parser_s.add_argument('DOMAIN',  help='Domain name')
         parser_s.set_defaults(subcommand='hostname')
         parser_t = subparsers.add_parser('ip', help='Search passive dns by IP, CIDR, or Range (v6 compatible)')
@@ -94,26 +105,36 @@ class CommandZetalytics(Command):
         parser_u = subparsers.add_parser('ip2malwaredns', help='Search malware dns by IP')
         parser_u.add_argument('IP',  help='IP address or CIDR or range IP')
         parser_u.set_defaults(subcommand='ip2malwaredns')
-        parser_v = subparsers.add_parser('ip2malwarehttp', help='Search malware http by IP/CIDR for http://x.x.x.x/ (not the IP a hostname resolved to). These results would not appear in the malware dns data since they do not require a DNS lookup.')
+        parser_v = subparsers.add_parser(
+            'ip2malwarehttp',
+            help='Search malware http by IP/CIDR for http://x.x.x.x/ (not the IP a hostname resolved to)')
         parser_v.add_argument('IP',  help='IP address or CIDR or range IP')
         parser_v.set_defaults(subcommand='ip2malwarehttp')
-        parser_w = subparsers.add_parser('ip2nsglue', help='Search name server glue (IP) records by IP, CIDR, or Range (v6 compatible)')
+        parser_w = subparsers.add_parser(
+            'ip2nsglue',
+            help='Search name server glue (IP) records by IP, CIDR, or Range (v6 compatible)')
         parser_w.add_argument('IP',  help='IP address or CIDR or range IP')
         parser_w.set_defaults(subcommand='ip2nsglue')
-        parser_x = subparsers.add_parser('mx2domain', help='Search passive dns by MX domain for any domain served by the MX domain')
+        parser_x = subparsers.add_parser(
+            'mx2domain',
+            help='Search passive dns by MX domain for any domain served by the MX domain')
         parser_x.add_argument('MX',  help='MX server')
         parser_x.set_defaults(subcommand='mx2domain')
-        parser_y = subparsers.add_parser('ns2domain', help='Search current zone files and passive DNS for domains served by nameserver. Note: start, end, and tsfield apply only to the passive results. Zone file records are from the most recent snapshot only, and will be excluded if end is less than yesterday')
+        parser_y = subparsers.add_parser(
+            'ns2domain',
+            help='Search current zone files and passive DNS for domains served by nameserver')
         parser_y.add_argument('NS',  help='NS server')
         parser_y.set_defaults(subcommand='ns2domain')
-        parser_z = subparsers.add_parser('subdomains', help='Search passive dns by domain for a list of subdomains from any record type')
+        parser_z = subparsers.add_parser(
+            'subdomains',
+            help='Search passive dns by domain for a list of subdomains from any record type')
         parser_z.add_argument('DOMAIN',  help='Domain name')
         parser_z.set_defaults(subcommand='subdomains')
         self.parser = parser
 
-    def run(self, conf, args, plugins):
+    def run(self, args, plugins):
         if 'subcommand' in args:
-            zeta = Zetalytics(token=conf['Zetalytics']['token'])
+            zeta = Zetalytics(token=self._config_data['Zetalytics']['token'])
             if args.subcommand == "cname2qname":
                 res = zeta.cname2qname(q=unbracket(args.CNAME))
                 if args.json:
@@ -129,7 +150,7 @@ class CommandZetalytics(Command):
                                 r['domain'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2aaaa":
+            elif args.subcommand == "domain2aaaa":
                 res = zeta.domain2aaaa(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -143,7 +164,7 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2cname":
+            elif args.subcommand == "domain2cname":
                 res = zeta.domain2cname(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -157,10 +178,10 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2d8s":
+            elif args.subcommand == "domain2d8s":
                 res = zeta.domain2d8s(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "domain2ip":
+            elif args.subcommand == "domain2ip":
                 res = zeta.domain2ip(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -174,13 +195,13 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2malwaredns":
+            elif args.subcommand == "domain2malwaredns":
                 res = zeta.domain2malwaredns(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "domain2malwarehttp":
+            elif args.subcommand == "domain2malwarehttp":
                 res = zeta.domain2malwarehttp(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "domain2mx":
+            elif args.subcommand == "domain2mx":
                 res = zeta.domain2mx(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -194,7 +215,7 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2ns":
+            elif args.subcommand == "domain2ns":
                 res = zeta.domain2ns(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -208,10 +229,10 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2nsglue":
+            elif args.subcommand == "domain2nsglue":
                 res = zeta.domain2nsglue(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "domain2ptr":
+            elif args.subcommand == "domain2ptr":
                 res = zeta.domain2ptr(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -225,7 +246,7 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2txt":
+            elif args.subcommand == "domain2txt":
                 res = zeta.domain2txt(q=unbracket(args.DOMAIN))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -239,10 +260,10 @@ class CommandZetalytics(Command):
                                 r['qname'],
                                 r['value']
                             ))
-            elif  args.subcommand == "domain2whois":
+            elif args.subcommand == "domain2whois":
                 res = zeta.domain2whois(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "email_address":
+            elif args.subcommand == "email_address":
                 res = zeta.email_address(q=unbracket(args.EMAIL))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -257,28 +278,28 @@ class CommandZetalytics(Command):
                                 r['d'],
                                 r["emails"][0]["addr"]
                             ))
-            elif  args.subcommand == "email_domain":
+            elif args.subcommand == "email_domain":
                 res = zeta.email_domain(q=unbracket(args.EMAIL))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "email_user":
+            elif args.subcommand == "email_user":
                 res = zeta.email_user(q=unbracket(args.EMAIL))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "hash2malwaredns":
-                if not re.fullmatch("[a-fA-F\d]{32}", args.HASH):
+            elif args.subcommand == "hash2malwaredns":
+                if not re.fullmatch(r"[a-fA-F\d]{32}", args.HASH):
                     print("Zetalytics only accept md5 hashes")
                 else:
                     res = zeta.hash2malwaredns(q=args.HASH)
                     print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "hash2malwarehttp":
-                if not re.fullmatch("[a-fA-F\d]{32}", args.HASH):
+            elif args.subcommand == "hash2malwarehttp":
+                if not re.fullmatch(r"[a-fA-F\d]{32}", args.HASH):
                     print("Zetalytics only accept md5 hashes")
                 else:
                     res = zeta.hash2malwarehttp(q=args.HASH)
                     print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "hostname":
+            elif args.subcommand == "hostname":
                 res = zeta.hostname(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "ip":
+            elif args.subcommand == "ip":
                 res = zeta.ip(q=unbracket(args.IP))
                 if args.json:
                     print(json.dumps(res, sort_keys=False, indent=4))
@@ -292,22 +313,22 @@ class CommandZetalytics(Command):
                                 r['last_seen'] if "last_seen" in r else "",
                                 r['qname']
                             ))
-            elif  args.subcommand == "ip2malwaredns":
+            elif args.subcommand == "ip2malwaredns":
                 res = zeta.ip2malwaredns(q=unbracket(args.IP))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "ip2malwarehttp":
+            elif args.subcommand == "ip2malwarehttp":
                 res = zeta.ip2malwarehttp(q=unbracket(args.IP))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "ip2nsglue":
+            elif args.subcommand == "ip2nsglue":
                 res = zeta.ip2nsglue(q=unbracket(args.IP))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "mx2domain":
+            elif args.subcommand == "mx2domain":
                 res = zeta.mx2domain(q=unbracket(args.MX))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "ns2domain":
+            elif args.subcommand == "ns2domain":
                 res = zeta.ns2domain(q=unbracket(args.NS))
                 print(json.dumps(res, sort_keys=False, indent=4))
-            elif  args.subcommand == "subdomains":
+            elif args.subcommand == "subdomains":
                 res = zeta.subdomains(q=unbracket(args.DOMAIN))
                 print(json.dumps(res, sort_keys=False, indent=4))
             else:
@@ -315,8 +336,9 @@ class CommandZetalytics(Command):
         else:
             self.parser.print_help()
 
-    def intel(self, type, query, data, conf):
-        zeta = Zetalytics(token=conf['Zetalytics']['token'])
+    def intel(self, type, query, data):
+        # TODO: support emails in here
+        zeta = Zetalytics(token=self._config_data['Zetalytics']['token'])
         if type == "domain":
             print("[+] Checking Zetalytics...")
             res = zeta.domain2ip(q=query)
@@ -329,8 +351,8 @@ class CommandZetalytics(Command):
                             "first": parse(domain['date']).astimezone(pytz.utc),
                             "last": parse(domain['last_seen']).astimezone(pytz.utc) if "last_seen" in domain else None,
                         })
-                    #else:
-                        #data["subdomains"].append(domain["qname"])
+                    # else:
+                        # data["subdomains"].append(domain["qname"])
         elif type == "ip":
             print("[+] Checking Zetalytics...")
             res = zeta.ip(q=query)
